==> isolate_bloc-0.0.1.tar.gz: lib/src/common/isolate_manager.dart <==
import 'dart:async';
import 'dart:isolate';

import 'bloc_manager.dart';

typedef IsolateRun = void Function(IsolateMessenger messager, Initializer data);

class IsolateManager {
  final Isolate isolate;
  final IsolateMessenger messenger;

  IsolateManager._(this.isolate, this.messenger);

  /// Create Isolate, initialize messages and run your function with [IsolateMessenger] and user's [Initializer] func
  static Future<IsolateManager> createIsolate(IsolateRun run, Initializer initializer) async {
    final fromIsolate = ReceivePort();
    final toIsolateCompleter = Completer<SendPort>();
    final isolate = await Isolate.spawn<IsolateSetup>(
        _runInIsolate, IsolateSetup(fromIsolate.sendPort, run, initializer));
    final fromIsolateStream = fromIsolate.asBroadcastStream();
    var subscription = fromIsolateStream.listen((message) {
      if (message is SendPort) {
        toIsolateCompleter.complete(message);
      }
    });
    final toIsolate = await toIsolateCompleter.future;
    subscription.cancel();
    return IsolateManager._(isolate, IsolateMessenger(fromIsolateStream, toIsolate.send));
  }

  static Future<void> _runInIsolate(IsolateSetup setup) async {
    final toIsolate = ReceivePort();
    final toIsolateStream = toIsolate.asBroadcastStream();
    setup.fromIsolate.send(toIsolate.sendPort);
    final isolateMessager = IsolateMessenger(toIsolateStream, setup.fromIsolate.send);
    setup.task(isolateMessager, setup.userInitializer);
  }
}

class IsolateSetup {
  final SendPort fromIsolate;
  final Initializer userInitializer;
  final IsolateRun task;

  IsolateSetup(this.fromIsolate, this.task, this.userInitializer);
}

class IsolateMessenger {
  final Stream<Object> _fromIsolateStream;
  final void Function(Object message) _toIsolate;

  IsolateMessenger(this._fromIsolateStream, this._toIsolate);

  Stream<Object> get reciveMessages => _fromIsolateStream;
  void sendMessage(Object message) => _toIsolate(message);
}

==> isolate_bloc-0.1.0.tar.gz: lib/src/common/isolate_manager.dart <==
import 'dart:async';
import 'dart:isolate';

import 'bloc_manager.dart';

typedef IsolateRun = void Function(IsolateMessenger messager, Initializer data);

class IsolateManager {
  final Isolate isolate;
  final IsolateMessenger messenger;

  IsolateManager._(this.isolate, this.messenger);

  /// Create Isolate, initialize messages and run your function with [IsolateMessenger] and user's [Initializer] func
  static Future<IsolateManager> createIsolate(
      IsolateRun run, Initializer initializer) async {
    final fromIsolate = ReceivePort();
    final toIsolateCompleter = Completer<SendPort>();
    final isolate = await Isolate.spawn<IsolateSetup>(
        _runInIsolate, IsolateSetup(fromIsolate.sendPort, run, initializer));
    final fromIsolateStream = fromIsolate.asBroadcastStream();
    var subscription = fromIsolateStream.listen((message) {
      if (message is SendPort) {
        toIsolateCompleter.complete(message);
      }
    });
    final toIsolate = await toIsolateCompleter.future;
    subscription.cancel();
    return IsolateManager._(
        isolate, IsolateMessenger(fromIsolateStream, toIsolate.send));
  }

  static Future<void> _runInIsolate(IsolateSetup setup) async {
    final toIsolate = ReceivePort();
    final toIsolateStream = toIsolate.asBroadcastStream();
    setup.fromIsolate.send(toIsolate.sendPort);
    final isolateMessenger =
        IsolateMessenger(toIsolateStream, setup.fromIsolate.send);
    setup.task(isolateMessenger, setup.userInitializer);
  }
}

class IsolateSetup {
  final SendPort fromIsolate;
  final Initializer userInitializer;
  final IsolateRun task;

  IsolateSetup(this.fromIsolate, this.task, this.userInitializer);
}

class IsolateMessenger {
  final Stream<Object> _fromIsolateStream;
  final void Function(Object message) _toIsolate;

  IsolateMessenger(this._fromIsolateStream, this._toIsolate);

  Stream<Object> get receiveMessages => _fromIsolateStream;

  void sendMessage(Object message) => _toIsolate(message);
}
